;; Generated package description from beframe.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "beframe" "1.5.0.0.20260605.5" "Isolate buffers per frame" '((emacs "28.1")) :commit "e4d0b4e5823c3137a70ca3f5d367c76bfadd0db0" :authors '(("Protesilaos" . "info@protesilaos.com")) :maintainer '("Protesilaos" . "info@protesilaos.com") :url "https://github.com/protesilaos/beframe")
